@@ -27,7 +27,7 @@ class CacheEntry {
 	public:
 		/** Constructs a cache entry with number of slots for grammar error
 		 *  suggestions */
-		CacheEntry(size_t suggestionCount);
+		explicit CacheEntry(size_t suggestionCount);
 	
 		/** Grammar error */
 		voikko_grammar_error error;
