@@ -27,10 +27,10 @@
 # include <pwd.h>
 # include <dirent.h>
 #endif
-#include <malaga.h>
+#include "morphology/malaga/malaga.hpp"
 
 #define VOIKKO_DICTIONARY_FILE "voikko-fi_FI.pro"
-#define VOIKKO_DICTIONARY_VERSION "1"
+#define VOIKKO_DICTIONARY_VERSION "2"
 #define VOIKKO_DICTIONARY_VERSION_KEY "info: Voikko-Dictionary-Format: " VOIKKO_DICTIONARY_VERSION
 #ifdef WIN32
 # define VOIKKO_KEY                   "SOFTWARE\\Voikko"
@@ -39,6 +39,7 @@
 #endif
 
 using namespace std;
+using namespace libvoikko::morphology::malaga;
 
 namespace libvoikko { namespace setup {
 
